#' ---
#' output:
#'   md_document:
#'     pandoc_args:
#'       - '--from=markdown-implicit_figures'
#'       - '--to=commonmark'
#'       - '--wrap=preserve'
#' ---



#+ reprex-setup, include = FALSE
options(tidyverse.quiet = TRUE)
knitr::opts_chunk$set(collapse = TRUE, comment = "#>", error = TRUE)
knitr::opts_knit$set(upload.fun = knitr::imgur_upload)

#+ reprex-body
library("reprex")
library("evaluator")
library("readr")

wd = "~/Documents/Code/Evaluator"
setwd(wd)



# create Excel templates in base directory

create_templates(base_directory = wd)


##  Modify/customize input spreadsheet manually before completing next steps


## If you have a different domain structure (e.g. ISO2700x, NIST CSF, or COBIT), you will need to edit the inputs/domains.csv file to include the domain names and the domain IDs,
### and a shorthand abbreviation for the domain (such as POL for the Policy domain).

# read domains from CSV files
domains = read_csv("./inputs/domains.csv")

# read the import spreadsheet and generate CSV files from it
import_spreadsheet("./inputs/survey.xlsx", domains, output_dir = "./inputs")

#  but ... does not update risk_tolerances.csv or domains.csv  (maybe customize)

# read in the FAIR parameters from CSV files, then validate
qualitative_scenarios <- readr::read_csv("./inputs/qualitative_scenarios.csv")
mappings <- readr::read_csv("./inputs/qualitative_mappings.csv")
capabilities <- readr::read_csv("./inputs/capabilities.csv")
validate_scenarios(qualitative_scenarios, capabilities, domains, mappings)

# Encode scenarios, coverting qualitative (ordinal) variables to quantitative 
quantitative_scenarios <- encode_scenarios(qualitative_scenarios, 
                                           capabilities, mappings)

## QUESTION -- where are the parameters/rules for converting qualitative FAIR to quant?


# Run the simulation 

simulation_results <- run_simulations(quantitative_scenarios, 
                                      iterations = 100L)
# Error: All scenarios must be tidyrisk_scenario objects



# saveRDS(simulation_results, file = "./results/simulation_results.rds")



#' <sup>Created on `r Sys.Date()` by the [reprex package](https://reprex.tidyverse.org) (v`r utils::packageVersion("reprex")`)</sup>


